@@ -1,9 +1,9 @@
 WBB_BASE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/pbp/parquet/play_by_play_{season}.parquet'
-WBB_TEAM_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/team_box/parquet/player_box_{season}.parquet'
+WBB_TEAM_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/team_box/parquet/team_box_{season}.parquet'
 WBB_PLAYER_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/player_box/parquet/player_box_{season}.parquet'
 WBB_TEAM_LOGO_URL  = 'https://github.com/saiemgilani/wehoop-data/blob/master/wbb/teams_colors_logos.csv'
-WBB_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/schedules/parquet/schedules_{season}.parquet'
+WBB_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wbb/schedules/parquet/wbb_schedule_{season}.parquet'
 WNBA_BASE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/pbp/parquet/play_by_play_{season}.parquet'
 WNBA_TEAM_BOX_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/team_box/parquet/team_box_{season}.parquet'
 WNBA_PLAYER_BOX_URL  = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/player_box/parquet/player_box_{season}.parquet'
-WNBA_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/schedules/parquet/schedules_{season}.parquet'
+WNBA_TEAM_SCHEDULE_URL = 'https://raw.githubusercontent.com/saiemgilani/wehoop-data/master/wnba/schedules/parquet/wnba_schedule_{season}.parquet'
